mailr3564 - /1.3/prompt/spin.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on November 18, 2007 - 21:04:
Author: bugman
Date: Sun Nov 18 21:04:56 2007
New Revision: 3564

URL: http://svn.gna.org/viewcvs/relax?rev=3564&view=rev
Log:
Implemented the spin.display() user function.


Modified:
    1.3/prompt/spin.py

Modified: 1.3/prompt/spin.py
URL: 
http://svn.gna.org/viewcvs/relax/1.3/prompt/spin.py?rev=3564&r1=3563&r2=3564&view=diff
==============================================================================
--- 1.3/prompt/spin.py (original)
+++ 1.3/prompt/spin.py Sun Nov 18 21:04:56 2007
@@ -199,27 +199,27 @@
         spin.delete(spin_id=spin_id)
 
 
-    def display(self, res_id=None):
-        """Function for displaying information about the residue(s).
-
-        Keyword Arguments
-        ~~~~~~~~~~~~~~~~~
-
-        res_id:  The residue identification string.
-        """
-
-        # Function intro text.
-        if self.__relax__.interpreter.intro:
-            text = sys.ps3 + "residue.display("
-            text = text + "res_id=" + `res_id` + ")"
-            print text
-
-        # The res_id argument.
-        if type(res_id) != str:
-            raise RelaxStrError, ('residue identification string', res_id)
-
-        # Execute the functional code.
-        residue.display(res_id=res_id)
+    def display(self, spin_id=None):
+        """Function for displaying information about the spin(s).
+
+        Keyword Arguments
+        ~~~~~~~~~~~~~~~~~
+
+        spin_id:  The spin identification string.
+        """
+
+        # Function intro text.
+        if self.__relax__.interpreter.intro:
+            text = sys.ps3 + "spin.display("
+            text = text + "spin_id=" + `spin_id` + ")"
+            print text
+
+        # The spin_id argument.
+        if type(spin_id) != str:
+            raise RelaxStrError, ('spin identification string', spin_id)
+
+        # Execute the functional code.
+        spin.display(spin_id=spin_id)
 
 
     def rename(self, res_id=None, new_name=None):




Related Messages


Powered by MHonArc, Updated Sun Nov 18 21:20:13 2007